import { BasicColumn, FormSchema } from '@/components/Table';
import { DescItem } from '@/components/Description';

export const sourceColumns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    slots: { customRender: 'name' },
    width: 120,
  },
  {
    title: '数据源状态',
    dataIndex: 'dataSourceStatus',
    width: 120,
  },
  {
    title: '类型',
    dataIndex: 'category',
    width: 120,
  },
  {
    title: '拥有者',
    dataIndex: 'owner',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 140,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 120,
  },
];

export const sourceSearchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    componentProps: {
      placeholder: '工作区名称',
    },
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'workSpaceName',
    label: '',
    componentProps: {
      placeholder: '所属工作区',
    },
    ifShow: false,
    component: 'Input',
    colProps: { span: 8 },
  },
];

// 表头
export const dbColumns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'dbName',
    slots: { customRender: 'dbName' },
    width: 200,
  },
  {
    title: '拥有者',
    dataIndex: 'owner',
    width: 180,
  },
  {
    title: '表数量',
    dataIndex: 'tableNumber',
    width: 150,
  },
];
export const dbSearchFormSchema: FormSchema[] = [
  {
    field: 'dbName',
    label: '',
    componentProps: {
      placeholder: '数据库名称',
    },
    component: 'Input',
    colProps: { span: 4 },
  },
];
// 表头
export const tbColumns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'tbName',
    slots: { customRender: 'tbName' },
    width: 200,
  },
  {
    title: '中文名',
    dataIndex: 'cnName',
    width: 180,
  },
  {
    title: '大小',
    dataIndex: 'size',
    width: 180,
  },
  {
    title: '存储类型',
    dataIndex: 'storageType',
    width: 180,
  },
];
export const tbSearchFormSchema: FormSchema[] = [
  {
    field: 'tbName',
    label: '',
    componentProps: {
      placeholder: '数据表名称',
    },
    component: 'Input',
    colProps: { span: 5 },
  },
  {
    field: 'storageType',
    label: '',
    componentProps: {
      // mode: 'multiple',
      placeholder: '存储类型',
      options: [
        {
          label: 'orc',
          value: 'orc',
        },
        {
          label: 'TORC',
          value: 'TORC',
        },
        {
          label: 'DM_InnoDB',
          value: 'DM_InnoDB',
        },
        {
          label: 'DM_MyISAM',
          value: 'DM_MyISAM',
        },
        {
          label: 'DM_Temporary',
          value: 'DM_Temporary',
        },
        {
          label: 'DM_Memory',
          value: 'DM_Memory',
        },
        {
          label: 'MyISAM',
          value: 'MyISAM',
        },
        {
          label: 'InnoDB',
          value: 'InnoDB',
        },
      ],
    },
    component: 'Select',
    colProps: { span: 5 },
  },
];
export const formSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '未完成',
      disabled: true,
      readOnly: true,
    },
    required: false,
  },
];

export const refundSchema: DescItem[] = [
  {
    field: 'dataSource',
    label: '数据源',
  },
  {
    field: 'size',
    label: '存储大小',
  },
  {
    field: 'type',
    label: '资产类型',
  },
  {
    field: 'owner',
    label: '拥有者',
  },
  {
    field: 'dataFrom',
    label: '元数据来源',
  },
  {
    field: 'zType',
    label: '压缩方式',
  },
  {
    field: 'changeTime',
    label: '表修改时间',
  },
  {
    field: 'isWork',
    label: '是否为事务表',
  },
  {
    field: 'storageType',
    label: '存储类型',
  },
  {
    field: 'createTime',
    label: '创建时间',
  },
  {
    field: 'updateTime',
    label: '更新时间',
  },
  {
    field: 'safeLevel',
    label: '安全等级',
  },
  {
    field: 'remark',
    label: '注释',
  },
  {
    field: 'storagePath',
    label: '存储路径',
  },
  {
    field: 'description',
    label: '描述',
  },
];
export const partitionSchema: DescItem[] = [
  {
    field: 'partitionType',
    label: '分区类型',
  },
];
export const partitionColumns: BasicColumn[] = [
  {
    title: '分页名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '分区键',
    dataIndex: 'partitionKey',
    width: 120,
  },
  {
    title: '分区键类型',
    dataIndex: 'partitionKeyType',
    width: 120,
  },
  {
    title: '分区范围',
    dataIndex: 'partitionSize',
    width: 120,
  },
];
export const bucketingSchema: DescItem[] = [
  {
    field: 'bucketingKey',
    label: '分桶键',
  },
  {
    field: 'num',
    label: '分桶个数',
  },
];
export const SampleDataColumns: BasicColumn[] = [
  {
    title: 'a_bigint',
    dataIndex: 'aBigint',
    width: 120,
  },
  {
    title: 'a_string',
    dataIndex: 'aString',
    width: 120,
  },
  {
    title: 'a_char',
    dataIndex: 'aChar',
    width: 120,
  },
  {
    title: 'a_date',
    dataIndex: 'aDate',
    width: 120,
  },
  {
    title: 'a_double',
    dataIndex: 'aDouble',
    width: 120,
  },
  {
    title: 'a_float',
    dataIndex: 'aFloat',
    width: 120,
  },
  {
    title: 'a_int',
    dataIndex: 'aInt',
    width: 120,
  },
  {
    title: 'a_long',
    dataIndex: 'aLong',
    width: 120,
  },
  {
    title: 'a_short',
    dataIndex: 'aShort',
    width: 120,
  },
  {
    title: 'a_timestamp',
    dataIndex: 'aTimestamp',
    width: 120,
  },
  {
    title: 'a_varchar',
    dataIndex: 'aVarchar',
    width: 120,
  },
];
export const informationColumns: BasicColumn[] = [
  {
    title: '列名',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '列中文名',
    dataIndex: 'CNname',
    width: 120,
    edit: true,
  },
  {
    title: '字段类型',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '长度',
    dataIndex: 'length',
    width: 120,
  },
  {
    title: '精度',
    dataIndex: 'precision',
    width: 120,
  },
  {
    title: '可空',
    dataIndex: 'isNull',
    width: 120,
  },
  {
    title: '注释',
    dataIndex: 'remark',
    width: 120,
  },
  {
    title: '主键',
    dataIndex: 'primaryKey',
    width: 120,
  },
  {
    title: '外键',
    dataIndex: 'foreignKey',
    width: 120,
  },
  {
    title: '数据类型',
    dataIndex: 'dataType',
    width: 120,
    edit: true,
  },
  {
    title: '安全分级',
    dataIndex: 'safeLevel',
    width: 120,
    edit: true,
  },
  {
    title: '敏感状态',
    dataIndex: 'sensitiveStatus',
    width: 120,
    edit: true,
  },
];
export const exampleDataColumns: BasicColumn[] = [
  {
    title: 'id',
    dataIndex: 'id',
    width: 120,
  },
  {
    title: 'age',
    dataIndex: 'age',
    width: 120,
  },
  {
    title: 'name',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: 'gender',
    dataIndex: 'gender',
    width: 120,
  },
  {
    title: 'height',
    dataIndex: 'height',
    width: 120,
  },
  {
    title: 'email',
    dataIndex: 'email',
    width: 120,
  },
  {
    title: 'phone',
    dataIndex: 'phone',
    width: 120,
  },
];
export const CorrelationColumns: BasicColumn[] = [
  {
    title: '标准名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '标准编号',
    dataIndex: 'code',
    width: 120,
  },
  {
    title: '路径',
    dataIndex: 'path',
    width: 120,
  },
  {
    title: '关联描述',
    dataIndex: 'remark',
    width: 120,
  },
  {
    title: '关联字段',
    dataIndex: 'field',
    width: 120,
  },
  {
    title: '关联时间',
    dataIndex: 'date',
    width: 120,
  },
  {
    title: '操作用户',
    dataIndex: 'user',
    width: 120,
  },
];

export const recommendColumns: BasicColumn[] = [
  {
    title: '关联字段名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '关联字段注释',
    dataIndex: 'comment',
    width: 120,
  },
  {
    title: '标准中文名称',
    dataIndex: 'CNname',
    width: 120,
  },
  {
    title: '标准英文名称',
    dataIndex: 'ENname',
    width: 120,
  },
  {
    title: '标准编号',
    dataIndex: 'code',
    width: 120,
  },
  {
    title: '推荐度',
    dataIndex: ' level',
    width: 120,
  },
  {
    title: '映射描述',
    dataIndex: 'remark',
    width: 120,
    edit: true,
    editable: true,
  },
];
export const quotationSchema: FormSchema[] = [
  {
    field: 'name',
    label: '选择关联字段',
    component: 'Select',
    componentProps: {
      options: [
        { label: '字段1', value: '1' },
        { label: '字段2', value: '2' },
        { label: '字段3', value: '3' },
      ],
    },
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'standard',
    label: '选择数据标准',
    component: 'Select',
    componentProps: {
      options: [
        { label: '基础标准1', value: '1' },
        { label: '基础标准2', value: '2' },
        { label: '基础标准3', value: '3' },
      ],
    },
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'remark',
    label: '关联描述',
    component: 'InputTextArea',
    colProps: { lg: 24, md: 24 },
  },
];
export const connectionColumns: BasicColumn[] = [
  {
    title: '表名',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '数据库',
    dataIndex: 'dataBase',
    width: 120,
  },
  {
    title: '添加方式',
    dataIndex: 'path',
    width: 120,
  },
  {
    title: '关联类型',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '状态',
    dataIndex: 'status',
    width: 120,
  },
  {
    title: '所有者',
    dataIndex: 'user',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'date',
    width: 120,
  },
];
export const analysisColumns: BasicColumn[] = [
  {
    title: '关联对象',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '路径',
    dataIndex: 'dataBase',
    width: 120,
  },
  {
    title: '关联类型',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '关联度',
    dataIndex: 'level',
    width: 120,
  },
];
export const physicsColumns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '所属元模型',
    dataIndex: 'dataBase',
    width: 120,
  },
  {
    title: '路径',
    dataIndex: 'path',
    width: 120,
  },
  {
    title: '关联时间',
    dataIndex: 'connectTime',
    width: 120,
  },
  {
    title: '同步时间',
    dataIndex: 'date',
    width: 120,
  },
  {
    title: '操作用户',
    dataIndex: 'user',
    width: 120,
  },
];
export const physicsSchema: FormSchema[] = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    componentProps: {
      treeData: [
        {
          title: '物理模型',
          businessId: '1',
          parentId: '0',
          children: [
            {
              title: '工作区1',
              businessId: '11',
              parentId: '1',
              children: [
                {
                  title: '元模型1',
                  businessId: '111',
                  parentId: '11',
                },
                {
                  title: '元模型2',
                  businessId: '112',
                  parentId: '11',
                },
              ],
            },
            {
              title: '工作区2',
              businessId: '12',
              parentId: '1',
              children: [
                {
                  title: '元模型3',
                  businessId: '121',
                  parentId: '12',
                },
                {
                  title: '元模型4',
                  businessId: '122',
                  parentId: '12',
                },
              ],
            },
          ],
        },
      ],
      fieldNames: {
        label: 'title',
        value: 'businessId',
      },
    },
    colProps: { lg: 24, md: 24 },
    required: true,
  },
];
export const versionFormSchema: FormSchema[] = [
  {
    field: 'versionName',
    label: '版本名称',
    component: 'Input',
    colProps: { span: 8 },
  },
];
export const versionColumns: BasicColumn[] = [
  {
    title: '版本ID',
    dataIndex: 'versionId',
    width: 120,
  },
  {
    title: '版本名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '提交者',
    dataIndex: 'user',
    width: 120,
  },
  {
    title: '提交时间',
    dataIndex: 'date',
    width: 120,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    width: 120,
  },
];
export const versionSchema: DescItem[] = [
  {
    field: 'dataSource',
    label: '数据源',
  },
  {
    field: 'type',
    label: '资产类型',
  },
  {
    field: 'owner',
    label: '拥有者',
  },
  {
    field: 'createTime',
    label: '版本生成时间',
  },
];
export const structureColumns: BasicColumn[] = [
  {
    title: '列名',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '字段类型',
    dataIndex: 'partitionKey',
    width: 120,
  },
  {
    title: '长度',
    dataIndex: 'length',
    width: 120,
  },
  {
    title: '精度',
    dataIndex: 'precision',
    width: 120,
  },
  {
    title: '可空',
    dataIndex: 'isNull',
    width: 120,
  },
  {
    title: '注释',
    dataIndex: 'remark',
    width: 120,
  },
];
export const indexColumns: BasicColumn[] = [
  {
    title: '索引类型',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '索引名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '索引字段',
    dataIndex: 'field',
    width: 120,
  },
  {
    title: '额外参数',
    dataIndex: 'precision',
    width: 120,
  },
];
export const bucketingColumns: BasicColumn[] = [
  {
    title: '分桶数',
    dataIndex: 'num',
    width: 120,
  },
  {
    title: '分桶字段',
    dataIndex: 'field',
    width: 120,
  },
  {
    title: '排序',
    dataIndex: 'index',
    width: 120,
  },
];
export const versionNumSchema: FormSchema[] = [
  {
    field: 'name',
    label: '查看版本',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'V1', value: '1' },
        { label: 'V2', value: '2' },
        { label: 'V3', value: '3' },
      ],
    },
    defaultValue: '1',
    colProps: { lg: 6, md: 6 },
  },
];
export const viewColumns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 60,
  },
  {
    title: '描述',
    dataIndex: 'remark',
    width: 120,
  },
  {
    title: 'SQL',
    dataIndex: 'sql',
    width: 180,
  },
];
export const storedColumns: BasicColumn[] = [
  {
    title: '存储过程名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '描述',
    dataIndex: 'remark',
    width: 120,
  },
  {
    title: '包头',
    dataIndex: 'sql',
    width: 120,
  },
  {
    title: '参数类型',
    dataIndex: 'type',
    width: 120,
  },
];
export const metaDataSchema: DescItem[] = [
  {
    field: 'dataSource',
    label: '数据源',
  },
  {
    field: 'type',
    label: '资产类型',
  },
  {
    field: 'owner',
    label: '拥有者',
  },
  {
    field: 'storageType',
    label: '存储类型',
  },
  {
    field: 'createTime',
    label: '创建时间',
  },
  {
    field: 'updateTime',
    label: '更新时间',
  },
  {
    field: 'remark',
    label: '注释',
  },
  {
    field: 'description',
    label: '描述',
  },
];
export const dataBaseSchema: DescItem[] = [
  {
    field: 'dataSource',
    label: '数据源',
  },
  {
    field: 'size',
    label: '存储大小',
  },
  {
    field: 'type',
    label: '资产类型',
  },
  {
    field: 'owner',
    label: '拥有者',
  },
  {
    field: 'dataFrom',
    label: '元数据来源',
  },
  {
    field: 'storageType',
    label: '存储类型',
  },
  {
    field: 'createTime',
    label: '创建时间',
  },
  {
    field: 'updateTime',
    label: '更新时间',
  },
  {
    field: 'safeLevel',
    label: '安全等级',
  },
  {
    field: 'remark',
    label: '注释',
  },
  {
    field: 'storagePath',
    label: '存储路径',
  },
  {
    field: 'description',
    label: '描述',
  },
];
export const addDataBaseSchema: FormSchema[] = [
  {
    field: 'name',
    label: '数据库名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
];
export const storageManagementColumns: BasicColumn[] = [
  {
    title: '清理开始时间',
    dataIndex: 'startTime',
    width: 120,
  },
  {
    title: '清理结束时间',
    dataIndex: 'endTime',
    width: 120,
  },
  {
    title: '执行耗时',
    dataIndex: 'useTime',
    width: 80,
  },
  {
    title: '执行状态',
    dataIndex: 'status',
    width: 120,
  },
  {
    title: '清理策略',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '清理表顶点数',
    dataIndex: 'pointNum',
    width: 120,
  },
  {
    title: '清理血缘关系树',
    dataIndex: 'num',
    width: 120,
  },
  {
    title: '操作者',
    dataIndex: 'user',
    width: 80,
  },
];
export const storageManagementFormSchema: FormSchema[] = [
  {
    field: 'startTime',
    label: '清理开始时间',
    component: 'DatePicker',
    colProps: { lg: 4, md: 4 },
  },
  {
    field: 'endTime',
    label: '清理结束时间',
    component: 'DatePicker',
    colProps: { lg: 4, md: 4 },
  },
  {
    field: 'user',
    label: '清理者',
    component: 'Input',
    colProps: { lg: 4, md: 4 },
  },
  {
    field: 'type',
    label: '清理策略',
    component: 'Select',
    componentProps: {
      options: [
        { label: '手动清理', value: '1' },
        { label: '自动清理', value: '2' },
      ],
    },
    colProps: { lg: 4, md: 4 },
  },
];
export const importFormSchema: FormSchema[] = [
  {
    field: 'file',
    component: 'Upload',
    label: '上传',
    colProps: { lg: 24, md: 24 },
    rules: [{ required: true, message: '请选择上传文件' }],
  },
  {
    field: 'flag',
    label: '文件重名',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '全部替换', value: '0' },
        { label: '全部放弃', value: '1' },
      ],
    },
    required: true,
  },
];
export const addTagSchema: FormSchema[] = [
  {
    field: 'name',
    label: '选择分类',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'zz1', value: '1' },
        { label: 'test2', value: '2' },
        { label: 'eeee3', value: '3' },
      ],
    },
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'tag',
    label: '选择标签',
    component: 'Select',
    componentProps: {
      mode: 'multiple',
      options: [
        { label: 'qqqq', value: '1' },
        { label: 'www', value: '2' },
        { label: 'eew', value: '3' },
        { label: 'wadwad', value: '4' },
      ],
    },
    colProps: { lg: 24, md: 24 },
    required: true,
  },
];
export const tagSchema: FormSchema[] = [
  {
    field: 'typeNum',
    label: '操作类型',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '新增标签', value: '0' },
        { label: '删除标签', value: '1' },
      ],
    },
    required: true,
  },
  {
    field: 'workName',
    label: '任务名',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'remark',
    label: '描述',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'range',
    label: '打标范围',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '数据源', value: '0' },
        { label: '数据库', value: '1' },
      ],
    },
    required: true,
  },
];
export const tagDataSourceColumns: BasicColumn[] = [
  {
    title: '数据源名',
    dataIndex: 'name',
    width: 120,
    edit: true,
  },
];
export const tagDataBaseColumns: BasicColumn[] = [
  {
    title: '数据库名',
    dataIndex: 'name',
    width: 120,
    edit: true,
  },
];
export const tagSourceColumns: BasicColumn[] = [
  {
    title: '标签名',
    dataIndex: 'tagName',
    width: 120,
    edit: true,
  },
  {
    title: '标签分类',
    dataIndex: 'tag',
    width: 120,
    edit: true,
  },
];
export const tagDataSourceFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    colProps: { span: 8 },
  },
];
export const tagRuleSchema: FormSchema[] = [
  {
    field: 'dataSourceName',
    label: '元数据名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'isPhysics',
    label: '是否为物理模型',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '是', value: '0' },
        { label: '否', value: '1' },
      ],
    },
    required: true,
  },
];
export const tagRecordColumns: BasicColumn[] = [
  {
    title: '打标时间',
    dataIndex: 'date',
    width: 120,
  },
  {
    title: '操作者',
    dataIndex: 'user',
    width: 120,
  },
  {
    title: '任务名',
    dataIndex: 'workName',
    width: 120,
  },
  {
    title: '打标数量',
    dataIndex: 'num',
    width: 120,
  },
  {
    title: '操作类型',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '执行状态',
    dataIndex: 'executionStatus',
    width: 120,
  },
];
export const tagRecordFormSchema: FormSchema[] = [
  {
    field: 'date',
    label: '打标时间',
    component: 'DatePicker',
    colProps: { lg: 6, md: 6 },
  },
  {
    field: 'executionStatus',
    label: '执行状态',
    component: 'Select',
    colProps: { lg: 6, md: 6 },
    componentProps: {
      options: [
        { label: '成功', value: '0' },
        { label: '失败', value: '1' },
      ],
    },
  },
  {
    field: 'type',
    label: '操作类型',
    component: 'Select',
    colProps: { lg: 6, md: 6 },
    componentProps: {
      options: [
        { label: '新增标签', value: '0' },
        { label: '删除标签', value: '1' },
      ],
    },
  },
];
export const physicsChangeSchema: FormSchema[] = [
  {
    field: 'path',
    label: '存储路径',
    component: 'TreeSelect',
    componentProps: {
      treeData: [
        {
          title: '物理模型',
          businessId: '1',
          parentId: '0',
          children: [
            {
              title: '工作区1',
              businessId: '11',
              parentId: '1',
              children: [
                {
                  title: '元模型1',
                  businessId: '111',
                  parentId: '11',
                },
                {
                  title: '元模型2',
                  businessId: '112',
                  parentId: '11',
                },
              ],
            },
            {
              title: '工作区2',
              businessId: '12',
              parentId: '1',
              children: [
                {
                  title: '元模型3',
                  businessId: '121',
                  parentId: '12',
                },
                {
                  title: '元模型4',
                  businessId: '122',
                  parentId: '12',
                },
              ],
            },
          ],
        },
      ],
      fieldNames: {
        label: 'title',
        value: 'businessId',
      },
    },
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'flag',
    label: '文件重名',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '全部覆盖', value: '0' },
        { label: '全部放弃', value: '1' },
        { label: '自动重命名', value: '2' },
      ],
    },
    required: true,
  },
];
export const tagSelectSchema: FormSchema[] = [
  {
    field: 'typeNum',
    label: '操作类型',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '新增标签', value: '0' },
        { label: '删除标签', value: '1' },
      ],
    },
    required: true,
  },
];
